#!/usr/bin/env python

"""
mod_python classes.
"""

import Generic
from mod_python.util import FieldStorage
from mod_python import apache

class Transaction(Generic.Transaction):

    """
    mod_python transaction interface.
    """

    def __init__(self, trans):

        "Initialise the transaction using the mod_python transaction 'trans'."

        self.trans = trans
        self.response_code = apache.OK

    # Request-related methods.

    def get_request_stream(self):

        """
        A framework-specific method which returns the request stream for
        the transaction.
        """

        return self.trans

    def get_request_method(self):

        """
        A framework-specific method which gets the request method.
        """

        return self.trans.method

    def get_headers(self):

        """
        A framework-specific method which returns all request headers.
        """

        return self.trans.headers_in

    def get_header_values(self, key):

        """
        A framework-specific method which returns a list of all request header
        values associated with the given 'key'. Note that according to RFC 2616,
        'key' is treated as a case-insensitive string.
        """

        return self.convert_to_list(self.trans.headers_in.get(key))

    def get_content_type(self):

        """
        A framework-specific method which gets the content type specified on the
        request, along with the charset employed.
        """

        return self.parse_content_type(self.trans.content_type)

    def get_content_charsets(self):

        """
        Returns the character set preferences.
        """

        return self.parse_content_preferences(self.trans.headers_in["Accept-Charset"])

    def get_content_languages(self):

        """
        A framework-specific method which extracts language information from
        the transaction.
        """

        return self.parse_content_preferences(self.trans.headers_in["Accept-Language"])

    def get_path(self):

        """
        A framework-specific method which gets the entire path from the request.
        """

        return self.trans.uri

    def get_path_info(self):

        """
        A framework-specific method which gets the "path info" (the part of the
        URL after the resource name handling the current request) from the
        request.
        """

        return self.trans.path_info

    # Higher level request-related methods.

    def get_fields(self):

        """
        A framework-specific method which extracts the form fields from the
        transaction.
        """

        return FieldStorage(self.trans, keep_blank_values=1)

    def get_user(self):

        """
        A framework-specific method which extracts user information from the
        transaction.
        """

        return self.trans.user

    # Response-related methods.

    def get_response_stream(self):

        """
        A framework-specific method which returns the response stream for
        the transaction.
        """

        return self.trans

    def get_response_code(self):

        """
        Get the response code associated with the transaction. If no response
        code is defined, None is returned.
        """

        return self.response_code

    def set_response_code(self, response_code):

        """
        Set the 'response_code' using a numeric constant defined in the HTTP
        specification.
        """

        self.response_code = response_code

    def set_header(self, header, value):

        """
        Set the HTTP 'header' with the given 'value'.
        """

        self.trans.headers_out[self.format_header_value(header)] = self.format_header_value(value)

    def set_content_type(self, content_type):

        """
        A framework-specific method which sets the 'content_type' for the
        response.
        """

        self.trans.content_type = self.format_content_type(content_type)

# vim: tabstop=4 expandtab shiftwidth=4
